==> scripts-0.1.3.tgz: package/common/start.js <==
const webpackDevServer = require('webpack-dev-server');
const webpack = require('webpack');
const open = require('open');
const appConfig = require('./appConfig');
const getEnvironmentInfo = require('./extendEnv');
const { parseArgsToJson, getProjectPath } = require('./utils');

function openStartRun(webpackFactory) {
  process.env.BABEL_ENV = 'development';
  process.env.NODE_ENV = 'development';

  const PORT = process.env.PORT || parseArgsToJson.port || appConfig.startDefaultPort;
  const HOST = process.env.HOST || '0.0.0.0';

  const extendEnv = getEnvironmentInfo();

  const options = {
    contentBase: getProjectPath(appConfig.startOutput.path),
    hot: true,
    host: HOST,
    quiet: true,
    publicPath: appConfig.startOutput.publicPath || '/',
    compress: true,
    overlay: false,
    historyApiFallback: {
      // https://github.com/facebook/create-react-app/issues/387.
      disableDotRule: true
    },
    watchOptions: {
      aggregateTimeout: 300,
      poll: 1000,
      ignored: /node_modules/
    },
    disableHostCheck: true
  };

  const startOpenPath = appConfig.startOpenPath ? appConfig.startOpenPath : '';

  try {
    const config = webpackFactory({ ...appConfig, port: PORT, startOpenPath }, extendEnv);

    webpackDevServer.addDevServerEntrypoints(config, options);
    const compiler = webpack(config);
    // eslint-disable-next-line new-cap
    const server = new webpackDevServer(compiler, options);

    server.listen(PORT, HOST, err => {
      if (err) {
        // eslint-disable-next-line no-console
        console.log(err);
        return;
      }
      open(`http://localhost:${PORT}${startOpenPath}`);
    });

    ['SIGINT', 'SIGTERM'].forEach(sig => {
      process.on(sig, () => {
        server.close();
        process.exit();
      });
    });
  } catch (err) {
    if (err && err.message) {
      // eslint-disable-next-line no-console
      console.log(err.message);
    }
    process.exit(1);
  }
}

module.exports = openStartRun;

==> scripts-1.0.5.tgz: package/common/start.js <==
const WebpackDevServer = require('webpack-dev-server');
const webpack = require('webpack');
const open = require('open');
const appConfig = require('./appConfig');
const getEnvironmentInfo = require('./extendEnv');
const { parseArgsToJson, getProjectPath } = require('./utils');

function openStartRun(webpackFactory) {
  process.env.BABEL_ENV = 'development';
  process.env.NODE_ENV = 'development';

  const PORT = process.env.PORT || parseArgsToJson.port || appConfig.startDefaultPort;
  const HOST = process.env.HOST || '0.0.0.0';

  const extendEnv = getEnvironmentInfo();

  const options = {
    allowedHosts: 'all',
    hot: true,
    host: HOST,
    port: PORT,
    compress: true,
    historyApiFallback: {
      // https://github.com/facebook/create-react-app/issues/387.
      disableDotRule: true
    },
    client: {
      overlay: false,
      progress: false
    },
    static: {
      directory: getProjectPath(appConfig.startOutput.path),
      publicPath: appConfig.startOutput.publicPath || '/',
      watch: {
        aggregateTimeout: 300,
        poll: 1000,
        ignored: /node_modules/
      }
    }
  };

  const startOpenPath = appConfig.startOpenPath ? appConfig.startOpenPath : '';

  try {
    const config = webpackFactory({ ...appConfig, port: PORT, startOpenPath }, extendEnv);
    const compiler = webpack(config);
    const server = new WebpackDevServer(options, compiler);

    server.startCallback(err => {
      if (err) {
        // eslint-disable-next-line no-console
        console.log(err);
        return;
      }
      open(`http://localhost:${PORT}${startOpenPath}`);
    });
    ['SIGINT', 'SIGTERM'].forEach(sig => {
      process.on(sig, () => {
        server.close();
        process.exit();
      });
    });
  } catch (err) {
    if (err && err.message) {
      // eslint-disable-next-line no-console
      console.log(err.message);
    }
    process.exit(1);
  }
}

module.exports = openStartRun;
